import RPIO.PWM as PWM

class robot:
	def __init__(self):
		self.left_drive = 0
		self.right_drive = 0
		self.LF_pin = 23
		self.RF_pin = 24
		self.LR_pin = 17
		self.RR_pin = 22

		self.pwm_channel = 0
		PWM.setup()
		PWM.init_channel(self.pwm_channel)
	
		self.commands = {'left': 0, 'forward': 0, 'right': 0, 'reverse': 0, 'speed': .5}

	def set_drive (self):
		#Get total motor states
		self.left_drive = self.commands['left']+self.commands['forward']-self.commands['right']-self.commands['reverse']
		self.right_drive = -self.commands['left']+self.commands['forward']+self.commands['right']-self.commands['reverse']
		#Normalize each motor state between -1:1
		max_val = max(abs(self.left_drive), abs(self.right_drive))
		if max_val == 0:
			max_val = 1
		normal_right  = (self.left_drive/max_val)*self.commands['speed']
		normal_left  = (self.right_drive/max_val)*self.commands['speed']
		self.left_drive = normal_left
		self.right_drive = normal_right
		print "left: {0} --- right: {1}".format(normal_left, normal_right)
		return normal_left, normal_right

	def safe_pulse(self, pin, intensity):
		start = 0
		#2000 turns the pulse on for 100% of the pulse cycle
		intensity = int(intensity * 1999)
		PWM.add_channel_pulse(self.pwm_channel, pin, start, intensity)

	def safe_clear(self, pin):
		try:
			PWM.clear_channel_gpio(self.pwm_channel, pin)
		except RuntimeError as e:
			print "Clear channel error: %s" % e

	def set_pins(self):
		#left drive
		if self.left_drive > 0 :
			self.safe_clear(self.LR_pin)
			self.safe_pulse(self.LF_pin, self.left_drive)
		elif self.left_drive < 0:
			self.safe_clear(self.LF_pin)
			self.safe_pulse(self.LR_pin, self.left_drive * -1)
		else:
			self.safe_clear(self.LF_pin)
			self.safe_clear(self.LR_pin)

		#right drive
		if self.right_drive > 0:
			self.safe_clear(self.RR_pin)
			self.safe_pulse(self.RF_pin, self.right_drive)
		elif self.right_drive < 0: 
			self.safe_clear(self.RF_pin)
			self.safe_pulse(self.RR_pin, -1 * self.right_drive)
		else:
			self.safe_clear(self.RR_pin)
			self.safe_clear(self.RF_pin)

